TildeExpr

Enum TildeExpr 

pub enum TildeExpr {
    Home,
    UserHome(String),
    WorkingDir,
    OldWorkingDir,
    NthDirFromTopOfDirStack {
        n: usize,
        plus_used: bool,
    },
    NthDirFromBottomOfDirStack {
        n: usize,
    },
}
Represents an expandable tilde expression (e.g., ~).

Variants



Home

~



UserHome(String)

~<user>



WorkingDir

~+



OldWorkingDir

~-



NthDirFromTopOfDirStack

Represents a tilde expansion of the form ~+N, referring to the Nth directory in the shell’s directory stack, starting at the top of the stack. Note that the directory stack is expected to contains the current working directory as its topmost entry.

Fields

n: usize

Index into the directory stack (zero-based: 0 is the top of the stack).

plus_used: bool

Whether the ‘+’ prefix was explicitly used.



NthDirFromBottomOfDirStack

Represents a tilde expansion of the form ~-N, referring to the Nth directory in the shell’s directory stack, starting at the bottom of the stack.

Fields

n: usize

Index into the directory stack (zero-based: 0 is the bottom of the stack).