pub enum TildeExpr {
Home,
UserHome(String),
WorkingDir,
OldWorkingDir,
NthDirFromTopOfDirStack {
n: usize,
plus_used: bool,
},
NthDirFromBottomOfDirStack {
n: usize,
},
}Expand description
Represents an expandable tilde expression (e.g., ~).
Variants
Home
~
UserHome(String)
~<user>
WorkingDir
~+
OldWorkingDir
~-
NthDirFromTopOfDirStack
Represents a tilde expansion of the form ~+N, referring to the Nth directory in
the shell’s directory stack, starting at the top of the stack. Note that the directory
stack is expected to contains the current working directory as its topmost entry.
Fields
NthDirFromBottomOfDirStack
Represents a tilde expansion of the form ~-N, referring to the Nth directory in
the shell’s directory stack, starting at the bottom of the stack.